---
search:
  exclude: true
---
# リリースプロセス／変更履歴

このプロジェクトは、`0.Y.Z` という形式を用いた、やや変更したセマンティック バージョニングに従います。先頭の `0` は、 SDK がまだ急速に進化していることを示します。各コンポーネントの更新は次のとおりです。

## マイナー (`Y`) バージョン

ベータではない公開インターフェースに対する  **破壊的変更**  がある場合、マイナー バージョン `Y` を上げます。たとえば、`0.0.x` から `0.1.x` への更新には破壊的変更が含まれる可能性があります。

破壊的変更を避けたい場合は、プロジェクトで `0.0.x` にピン留めすることをおすすめします。

## パッチ (`Z`) バージョン

後方互換のある変更には `Z` を増やします。

-   バグ修正
-   新機能
-   非公開インターフェースの変更
-   ベータ機能の更新

## 破壊的変更の変更履歴

### 0.2.0

このバージョンでは、以前は引数に `Agent` を受け取っていた箇所の一部が、代わりに引数として `AgentBase` を受け取るようになりました。たとえば、 MCP サーバーでの `list_tools()` 呼び出しです。これは純粋に型に関する変更であり、引き続き `Agent` オブジェクトを受け取ります。更新するには、`Agent` を `AgentBase` に置き換えて型エラーを修正するだけです。

### 0.1.0

このバージョンでは、[`MCPServer.list_tools()`][agents.mcp.server.MCPServer] に新しいパラメーターが 2 つ追加されました: `run_context` と `agent`。`MCPServer` をサブクラス化する任意のクラスに、これらのパラメーターを追加する必要があります。